@@ -11,7 +11,7 @@ use HTML::Template;
 use HTML::Template::Expr;
 use HTML::Template::Pro;
 
-our $VERSION = '0.99_09';
+our $VERSION = '0.99_10';
 
 our %feature_syntaxes = (
     literal_text              => <<END_OF_TEMPLATE,
@@ -84,9 +84,6 @@ sub benchmark_descriptions
         } );
 }
 
-#  TODO: all results are suspiciously constistent, I'm not sure
-#  TODO: it pays any attention to caching options at all.
-
 sub benchmark_functions_for_uncached_string
 {
     my ( $self ) = @_;
@@ -99,7 +96,6 @@ sub benchmark_functions_for_uncached_string
                     scalarref         => \$_[ 0 ],
                     case_sensitive    => 1,
                     die_on_bad_params => 0,
-                    cache             => 0,
                     );
                 $t->param( $_[ 1 ] );
                 $t->param( $_[ 2 ] );
@@ -124,8 +120,6 @@ sub benchmark_functions_for_uncached_disk
                     path              => \@template_dirs,
                     filename          => $_[ 0 ],
                     case_sensitive    => 1,
-                    file_cache        => 0,
-                    cache             => 0,
                     die_on_bad_params => 0,
                     );
                 $t->param( $_[ 1 ] );
@@ -139,85 +133,22 @@ sub benchmark_functions_for_uncached_disk
 sub benchmark_functions_for_disk_cache
 {
     my ( $self, $template_dir, $cache_dir ) = @_;
-    my ( @template_dirs );
 
-    @template_dirs = ( $template_dir );
-
-    return( {
-        HTP =>
-            sub
-            {
-                my $t = HTML::Template::Pro->new(
-                    path              => \@template_dirs,
-                    filename          => $_[ 0 ],
-                    case_sensitive    => 1,
-                    file_cache        => 1,
-                    file_cache_dir    => $cache_dir,
-                    cache             => 0,
-                    die_on_bad_params => 0,
-                    );
-                $t->param( $_[ 1 ] );
-                $t->param( $_[ 2 ] );
-                my $out = $t->output();
-                $out;
-            },
-        } );
+    return( undef );
 }
 
 sub benchmark_functions_for_shared_memory_cache
 {
     my ( $self, $template_dir, $cache_dir ) = @_;
-    my ( @template_dirs );
 
-#    #  TODO: some means to push this onto error stack?
-#    eval "use IPC::SharedCache";
-#    return( undef ) if $@;
-
-    @template_dirs = ( $template_dir );
-
-    return( {
-        HTP =>
-            sub
-            {
-                my $t = HTML::Template::Pro->new(
-                    path              => \@template_dirs,
-                    filename          => $_[ 0 ],
-                    case_sensitive    => 1,
-                    shared_cache      => 1,
-                    die_on_bad_params => 0,
-                    );
-                $t->param( $_[ 1 ] );
-                $t->param( $_[ 2 ] );
-                my $out = $t->output();
-                $out;
-            },
-        } );
+    return( undef );
 }
 
 sub benchmark_functions_for_memory_cache
 {
     my ( $self, $template_dir, $cache_dir ) = @_;
-    my ( @template_dirs );
 
-    @template_dirs = ( $template_dir );
-
-    return( {
-        HTP =>
-            sub
-            {
-                my $t = HTML::Template::Pro->new(
-                    path              => \@template_dirs,
-                    filename          => $_[ 0 ],
-                    case_sensitive    => 1,
-                    cache             => 1,
-                    die_on_bad_params => 0,
-                    );
-                $t->param( $_[ 1 ] );
-                $t->param( $_[ 2 ] );
-                my $out = $t->output();
-                $out;
-            },
-        } );
+    return( undef );
 }
 
 sub benchmark_functions_for_instance_reuse
